Changes
=======

Unreleased
----------

Version 0.4.2
-------------

Released 2023-07-03

- Add support for Python 3.11. `#97 <https://github.com/dajiaji/pyhpke/pull/97>`__
- Drop support for Python 3.7. `#95 <https://github.com/dajiaji/pyhpke/pull/95>`__
- Update dependencies.
    - Bump cryptography to 41.0.0. `#99 <https://github.com/dajiaji/pyhpke/pull/99>`__
- Update dev dependencies.
    - Bump pytest to 7.4.0. `#93 <https://github.com/dajiaji/pyhpke/pull/93>`__
    - Bump tox to 4.6.3. `#92 <https://github.com/dajiaji/pyhpke/pull/92>`__
    - Bump sphinx-rtd-theme to 1.2.2. `#90 <https://github.com/dajiaji/pyhpke/pull/90>`__
    - Bump pytest-cov to 4.1.0. `#85 <https://github.com/dajiaji/pyhpke/pull/85>`__

Version 0.4.1
-------------

Released 2023-02-18

- Add SECURITY.md. `#67 <https://github.com/dajiaji/pyhpke/pull/67>`__
- Use allowlist_externals on tox. `#37 <https://github.com/dajiaji/pyhpke/pull/37>`__
- Remove log. `#18 <https://github.com/dajiaji/pyhpke/pull/18>`__
- Update dependencies.
    - Bump cryptography to 39.0.1. `#64 <https://github.com/dajiaji/pyhpke/pull/64>`__
- Update dev dependencies.
    - Bump sphinx-rtd-theme to 1.2.0. `#66 <https://github.com/dajiaji/pyhpke/pull/66>`__
    - Bump tox to 4.4.5. `#65 <https://github.com/dajiaji/pyhpke/pull/65>`__
    - Bump black to 23.1.0. `#63 <https://github.com/dajiaji/pyhpke/pull/63>`__
    - Bump isort to 5.12.0. `#60 <https://github.com/dajiaji/pyhpke/pull/60>`__
    - Bump blacken-docs to 1.13.0. `#56 <https://github.com/dajiaji/pyhpke/pull/56>`__
    - Bump sphinx-autodoc-typehints to 1.21.0. `#55 <https://github.com/dajiaji/pyhpke/pull/55>`__
    - Bump pytest to 7.2.1. `#54 <https://github.com/dajiaji/pyhpke/pull/54>`__
    - Bump flake8 to 6.0.0. `#21 <https://github.com/dajiaji/pyhpke/pull/21>`__
    - Bump pre-commit-hooks to 4.4.0. `#21 <https://github.com/dajiaji/pyhpke/pull/21>`__

Version 0.4.0
-------------

Released 2022-11-15

- Add from_pyca_cryptography_key to KEMKey. `#16 <https://github.com/dajiaji/pyhpke/pull/16>`__
- Update dev dependencies.
    - Bump pre-commit/mirrors-mypy to 0.990. `#15 <https://github.com/dajiaji/pyhpke/pull/15>`__
    - Bump tox to 3.27.1. `#15 <https://github.com/dajiaji/pyhpke/pull/15>`__
    - Bump sphinx-rtd-theme to 1.1.1. `#13 <https://github.com/dajiaji/pyhpke/pull/13>`__

Version 0.3.0
-------------

Released 2022-11-05

- First public release.

Version 0.2.0
-------------

Released 2022-10-29

- Experimental release (3) based on https://github.com/ctz/hpke-py.

Version 0.1.1
-------------

Released 2022-10-16

- Experimental release (2) based on https://github.com/ctz/hpke-py.

Version 0.1.0
-------------

Released 2022-10-16

- Experimental release (1) based on https://github.com/ctz/hpke-py.
